SWDEV:253548 : remove gfx-arch macros
Change-Id: I1ef0b4e080c15a9c6228f48ecd6a65b134d0a72d
[ROCm/hip commit: a2f9a2d469]
This commit is contained in:
gecommit door
Sarbojit Sarkar
bovenliggende
8811d4d1a8
commit
0eebd71062
@@ -740,12 +740,9 @@ if($HIP_PLATFORM eq "hcc"){
|
||||
# Ignore 'gfx000' target reported by rocm_agent_enumerator.
|
||||
if ($val ne 'gfx000') {
|
||||
# Construct an arch macro to be passed to the compiler.
|
||||
# Example: gfx900 --> -D__HIP_ARCH_GFX900__=1
|
||||
my $archMacro = ' -D__HIP_ARCH_' . uc($val) . '__=1 ';
|
||||
# Add the arch option and macro to the compiler options.
|
||||
$GPU_ARCH_ARG = $GPU_ARCH_OPT . $val;
|
||||
$HIPLDARCHFLAGS .= $GPU_ARCH_ARG;
|
||||
$HIPCXXFLAGS .= $archMacro;
|
||||
if ($HIP_COMPILER eq 'clang' and $hasHIP) {
|
||||
$HIPCXXFLAGS .= $GPU_ARCH_ARG;
|
||||
}
|
||||
|
||||
@@ -29,13 +29,6 @@ THE SOFTWARE.
|
||||
#include "hip/hip_runtime.h"
|
||||
#include "test_common.h"
|
||||
|
||||
#if __HIP_ARCH_GFX803__ || \
|
||||
__HIP_ARCH_GFX900__ || \
|
||||
__HIP_ARCH_GFX906__ || \
|
||||
__HIP_ARCH_GFX908__ || \
|
||||
__HIP_ARCH_GFX1010__ || \
|
||||
__HIP_ARCH_GFX1012__
|
||||
|
||||
__global__ void kernel_abs_int64(long long *input, long long *output) {
|
||||
int tx = threadIdx.x;
|
||||
output[tx] = abs(input[tx]);
|
||||
@@ -46,8 +39,6 @@ __global__ void kernel_lgamma_double(double *input, double *output) {
|
||||
output[tx] = lgamma(input[tx]);
|
||||
}
|
||||
|
||||
#endif
|
||||
|
||||
#define CHECK_LGAMMA_DOUBLE(IN, OUT, EXP) \
|
||||
{ \
|
||||
if (OUT != EXP) { \
|
||||
|
||||
@@ -28,13 +28,6 @@ THE SOFTWARE.
|
||||
|
||||
#include "test_common.h"
|
||||
|
||||
#if __HIP_ARCH_GFX803__ || \
|
||||
__HIP_ARCH_GFX900__ || \
|
||||
__HIP_ARCH_GFX906__ || \
|
||||
__HIP_ARCH_GFX908__ || \
|
||||
__HIP_ARCH_GFX1010__ || \
|
||||
__HIP_ARCH_GFX1012__
|
||||
|
||||
__device__ void test_convert() {
|
||||
__half x;
|
||||
float y = (float)x;
|
||||
@@ -108,8 +101,6 @@ __global__ void testHalf2Abs(float2* p) {
|
||||
*p = __half22float2(a);
|
||||
}
|
||||
|
||||
#endif
|
||||
|
||||
|
||||
__half host_ushort_as_half(unsigned short s) {
|
||||
union {__half h; unsigned short s; } converter;
|
||||
|
||||
@@ -32,13 +32,6 @@ THE SOFTWARE.
|
||||
|
||||
using namespace std;
|
||||
|
||||
#if __HIP_ARCH_GFX803__ || \
|
||||
__HIP_ARCH_GFX900__ || \
|
||||
__HIP_ARCH_GFX906__ || \
|
||||
__HIP_ARCH_GFX908__ || \
|
||||
__HIP_ARCH_GFX1010__ || \
|
||||
__HIP_ARCH_GFX1012__
|
||||
|
||||
__global__
|
||||
void __halfTest(bool* result, __half a) {
|
||||
// Construction
|
||||
@@ -168,8 +161,6 @@ void __half2Test(bool* result, __half2 a) {
|
||||
#endif
|
||||
}
|
||||
|
||||
#endif
|
||||
|
||||
int main() {
|
||||
bool* result{nullptr};
|
||||
hipHostMalloc(&result, 1);
|
||||
|
||||
Verwijs in nieuw issue
Block a user